        function getT(rr,cc){
       if(rr==7 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==7 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>11</strong> miembros: 20 <br>1,4,6,9,11,16,19,20,21,22,23,25,27,28,31,34,40,41,47,50';}
       if(rr==7 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>0</strong> miembros: 14 <strong>control</strong><br>0,2,3,5,13,15,17,35,36,42,43,44,46,48';}
       if(rr==7 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>37</strong> miembros: 9 <br>10,12,14,24,26,33,37,38,49';}
       if(rr==7 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>45</strong> miembros: 8 <br>7,8,18,29,30,32,39,45';}
       if(rr==34 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==34 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>11</strong> miembros: 20 <br>1,4,6,9,11,16,19,20,21,22,23,25,27,28,31,34,40,41,47,50';}
       if(rr==34 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>0</strong> miembros: 14 <strong>control</strong><br>0,2,3,5,13,15,17,35,36,42,43,44,46,48';}
       if(rr==34 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>37</strong> miembros: 9 <br>10,12,14,24,26,33,37,38,49';}
       if(rr==34 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>45</strong> miembros: 8 <br>7,8,18,29,30,32,39,45';}
       if(rr==35 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==35 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>11</strong> miembros: 20 <br>1,4,6,9,11,16,19,20,21,22,23,25,27,28,31,34,40,41,47,50';}
       if(rr==35 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>0</strong> miembros: 14 <strong>control</strong><br>0,2,3,5,13,15,17,35,36,42,43,44,46,48';}
       if(rr==35 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>37</strong> miembros: 9 <br>10,12,14,24,26,33,37,38,49';}
       if(rr==35 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>45</strong> miembros: 8 <br>7,8,18,29,30,32,39,45';}
       if(rr==36 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==36 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>11</strong> miembros: 20 <br>1,4,6,9,11,16,19,20,21,22,23,25,27,28,31,34,40,41,47,50';}
       if(rr==36 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>0</strong> miembros: 14 <strong>control</strong><br>0,2,3,5,13,15,17,35,36,42,43,44,46,48';}
       if(rr==36 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>37</strong> miembros: 9 <br>10,12,14,24,26,33,37,38,49';}
       if(rr==36 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>45</strong> miembros: 8 <br>7,8,18,29,30,32,39,45';}
       if(rr==37 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==37 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>11</strong> miembros: 20 <br>1,4,6,9,11,16,19,20,21,22,23,25,27,28,31,34,40,41,47,50';}
       if(rr==37 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>0</strong> miembros: 14 <strong>control</strong><br>0,2,3,5,13,15,17,35,36,42,43,44,46,48';}
       if(rr==37 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>37</strong> miembros: 9 <br>10,12,14,24,26,33,37,38,49';}
       if(rr==37 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>45</strong> miembros: 8 <br>7,8,18,29,30,32,39,45';}
       if(rr==38 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==38 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>11</strong> miembros: 20 <br>1,4,6,9,11,16,19,20,21,22,23,25,27,28,31,34,40,41,47,50';}
       if(rr==38 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>0</strong> miembros: 14 <strong>control</strong><br>0,2,3,5,13,15,17,35,36,42,43,44,46,48';}
       if(rr==38 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>37</strong> miembros: 9 <br>10,12,14,24,26,33,37,38,49';}
       if(rr==38 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>45</strong> miembros: 8 <br>7,8,18,29,30,32,39,45';}
       if(rr==39 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==39 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>11</strong> miembros: 20 <br>1,4,6,9,11,16,19,20,21,22,23,25,27,28,31,34,40,41,47,50';}
       if(rr==39 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>0</strong> miembros: 14 <strong>control</strong><br>0,2,3,5,13,15,17,35,36,42,43,44,46,48';}
       if(rr==39 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>3</strong> representante: <strong>37</strong> miembros: 9 <br>10,12,14,24,26,33,37,38,49';}
       if(rr==39 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260615 a 12</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>4</strong> representante: <strong>45</strong> miembros: 8 <br>7,8,18,29,30,32,39,45';}
}
